import requests
from bs4 import BeautifulSoup

from akibapass_downloader.const import BASE_URL


def login(email: str, password: str) -> dict[str, str] | None:
    """Performs a login on the Akibapass site and returns a set of cookies
    to use while performing other requests."""
    login_page_req = requests.get(f"{BASE_URL}/login")
    if login_page_req.status_code != 200:
        return None

    page = BeautifulSoup(login_page_req.text, "html.parser")
    # Find the CSRF token's value.
    csrf_token = page.find("meta", attrs={"name": "csrf-token"}).attrs["content"]
    # Find the CSRD token's name.
    csrf_param = page.find("meta", attrs={"name": "csrf-param"}).attrs["content"]

    r = requests.post(
        f"{BASE_URL}/login",
        cookies={
            # Use the session we received on the login page.
            "_session": login_page_req.cookies["_session"],
        },
        data={
            "email": email,
            "password": password,
            csrf_param: csrf_token,
            "utf8": "✓",
        },
    )
    if r.status_code != 200:
        return None

    return {
        "_session": r.cookies["_session"],
    }
